summaryrefslogtreecommitdiff
path: root/lib/Target/ARM/ARMSubtarget.h
diff options
context:
space:
mode:
authorEvan Cheng <evan.cheng@apple.com>2011-07-01 21:01:15 +0000
committerEvan Cheng <evan.cheng@apple.com>2011-07-01 21:01:15 +0000
commit5b1b4489cf3a0f56f8be0673fc5cc380a32d277b (patch)
tree3bff4e3dc0b54a8d194d2c8714ac18873c32e820 /lib/Target/ARM/ARMSubtarget.h
parent94214703d97d8d9dfca88174ffc7e94820a85e62 (diff)
downloadllvm-5b1b4489cf3a0f56f8be0673fc5cc380a32d277b.tar.gz
llvm-5b1b4489cf3a0f56f8be0673fc5cc380a32d277b.tar.bz2
llvm-5b1b4489cf3a0f56f8be0673fc5cc380a32d277b.tar.xz
Rename TargetSubtarget to TargetSubtargetInfo for consistency.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@134259 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Target/ARM/ARMSubtarget.h')
-rw-r--r--lib/Target/ARM/ARMSubtarget.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/Target/ARM/ARMSubtarget.h b/lib/Target/ARM/ARMSubtarget.h
index fbe8322731..b73bbba907 100644
--- a/lib/Target/ARM/ARMSubtarget.h
+++ b/lib/Target/ARM/ARMSubtarget.h
@@ -7,14 +7,14 @@
//
//===----------------------------------------------------------------------===//
//
// This file declares the ARM specific subclass of TargetSubtarget.
//
//===----------------------------------------------------------------------===//
#ifndef ARMSUBTARGET_H
#define ARMSUBTARGET_H
-#include "llvm/Target/TargetSubtarget.h"
+#include "llvm/Target/TargetSubtargetInfo.h"
#include "llvm/MC/MCInstrItineraries.h"
#include "llvm/ADT/Triple.h"
#include <string>
@@ -228,7 +228,7 @@ protected:
/// enablePostRAScheduler - True at 'More' optimization.
bool enablePostRAScheduler(CodeGenOpt::Level OptLevel,
- TargetSubtarget::AntiDepBreakMode& Mode,
+ TargetSubtargetInfo::AntiDepBreakMode& Mode,
RegClassVector& CriticalPathRCs) const;
/// getInstrItins - Return the instruction itineraies based on subtarget
@@ -7,14 +7,14 @@
//===----------------------------------------------------------------------===//
//
-// This file declares the ARM specific subclass of TargetSubtarget.
+// This file declares the ARM specific subclass of TargetSubtargetInfo.
//
//===----------------------------------------------------------------------===//